class EasyUpiPaymentModel {
  const EasyUpiPaymentModel({
    required this.payeeVpa,
    required this.payeeName,
    required this.amount,
    required this.description,
    this.payeeMerchantCode,
    this.transactionId,
    this.transactionRefId,
  });

  /// It takes VPA address of payee for e.g. gaurav.jajoo@upi
  final String payeeVpa;

  /// It takes name of the payee like Gaurav Jajoo
  final String payeeName;

  /// Payee Merchant code. This should be valid.
  final String? payeeMerchantCode;

  /// This field is used in Merchant Payments generated by PSPs.
  /// if provided null then it will use [DateTime.now().microsecondsSinceEpoch]
  final String? transactionId;

  /// Transaction reference ID. This could be order number, subscription number, Bill ID, booking ID, insurance renewal reference, etc. Needed for merchant transactions and dynamic URL generation. This is mandatory because absence of this field generated error in apps like PhonePe
  /// if provided null then it will use [DateTime.now().millisecondsSinceEpoch]
  final String? transactionRefId;

  /// To provide a valid small note or description about payment.
  /// for e.g. for donating to Ram-mandir
  final String? description;

  /// It takes the amount in String decimal format (xx.xx) to be paid.
  /// For e.g. 90.88 will pay Rs. 90.88.
  final double amount;

  Map<String, String?> toMap() {
    return {
      'payeeVpa': payeeVpa,
      'payeeName': payeeName,
      'payeeMerchantCode': payeeMerchantCode ?? '',
      'transactionId':
          transactionId ?? DateTime.now().microsecondsSinceEpoch.toString(),
      'transactionRefId':
          transactionRefId ?? DateTime.now().millisecondsSinceEpoch.toString(),
      'description': description,
      'amount': amount.toString(),
    };
  }
}
